@@ -353,7 +353,7 @@ class BaseClient(WebSocketInteractor):
                 while retries_performed <= max_ratelimit_retries:
                     retry_after: int = 60 * 5
 
-                    self.logger.warn(f"Rate limit reached. Sleeping for: {retry_after}")
+                    self.logger.warn(f"Rate limit reached. Sleeping for: {retry_after} sec...")
                     time.sleep(retry_after + 1)
 
                     headers.update(self.__header_interceptor.intercept())
@@ -809,7 +809,7 @@ class Client(BaseClient):
     def set_user_role(self, call_id: int, user_id: int, role: str) -> dict:
         """
 
-        通話に参加中ののユーザーに役職を与えます
+        通話に参加中のユーザーに役職を与えます
 
         """
         return self.CallAPI.set_user_role(call_id, user_id, role)
